@@ -44,8 +44,8 @@ class MoesifMiddlewarePre19(object):
         self.client = MoesifAPIClient(self.middleware_settings.get('APPLICATION_ID'))
         # below comment for setting moesif base_uri to a test server.
         if self.middleware_settings.get('LOCAL_DEBUG', False):
-            Configuration.BASE_URI = self.middleware_settings.get('LOCAL_MOESIF_BASEURL', 'https://api.moesif.net')
-        Configuration.version = 'moesifdjango-python/2.0.2'
+            Configuration.BASE_URI = self.get_configuration_uri(self.middleware_settings, 'BASE_URI', 'LOCAL_MOESIF_BASEURL')
+        Configuration.version = 'moesifdjango-python/2.0.4'
         if settings.MOESIF_MIDDLEWARE.get('CAPTURE_OUTGOING_REQUESTS', False):
             try:
                 if self.DEBUG:
@@ -71,8 +71,8 @@ class MoesifMiddlewarePre19(object):
         self.sampling_percentage = 100
         self.config_etag = None
         self.last_updated_time = datetime.utcnow()
-        self.last_event_job_run_time = datetime.utcnow()
-        self.scheduler = BackgroundScheduler(daemon=True)
+        self.last_event_job_run_time = datetime(1970, 1, 1, 0, 0)  # Assuming job never ran, set it to epoch start time
+        self.scheduler = None
         self.event_queue_size = self.middleware_settings.get('EVENT_QUEUE_SIZE', 10000)
         self.mo_events_queue = queue.Queue(maxsize=self.event_queue_size)
         self.event_batch_size = self.middleware_settings.get('BATCH_SIZE', 25)
@@ -85,14 +85,14 @@ class MoesifMiddlewarePre19(object):
             if self.DEBUG:
                 print('Error while parsing application configuration on initialization')
         self.transaction_id = None
-        try:
-            self.schedule_event_background_job()
-            self.is_event_job_scheduled = True
-        except Exception as ex:
-            self.is_event_job_scheduled = False
-            if self.DEBUG:
-                print('Error while starting the event scheduler job in background')
-                print(str(ex))
+
+    # Function to get configuration uri
+    def get_configuration_uri(self, settings, field, deprecated_field):
+        uri = settings.get(field)
+        if uri:
+            return uri
+        else:
+            return settings.get(deprecated_field, 'https://api.moesif.net')
 
     # Function to listen to the send event job response
     def event_listener(self, event):
@@ -118,6 +118,8 @@ class MoesifMiddlewarePre19(object):
     # Function to schedule send event job in async
     def schedule_event_background_job(self):
         try:
+            if not self.scheduler:
+                self.scheduler = BackgroundScheduler(daemon=True)
             if not self.scheduler.get_jobs():
                 self.scheduler.add_listener(self.event_listener, EVENT_JOB_EXECUTED | EVENT_JOB_ERROR)
                 self.scheduler.start()
@@ -135,8 +137,6 @@ class MoesifMiddlewarePre19(object):
 
                 # Exit handler when exiting the app
                 atexit.register(lambda: self.job_scheduler.exit_handler(self.scheduler, self.DEBUG))
-            else:
-                self.last_event_job_run_time = datetime.utcnow()
         except Exception as ex:
             if self.DEBUG:
                 print("Error when scheduling the job")
@@ -144,7 +144,7 @@ class MoesifMiddlewarePre19(object):
 
     @classmethod
     def process_request(cls, request):
-        request.moesif_req_time = timezone.now()
+        request.moesif_req_time = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
         try:
             request._mo_body = request.body
             request._stream = BytesIO(request.body)
@@ -199,14 +199,14 @@ class MoesifMiddlewarePre19(object):
                                                                                         self.middleware_settings)
 
         # Response Time
-        rsp_time = timezone.now()
+        rsp_time = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
 
         # Prepare Event Request Model
-        event_req = self.event_mapper.to_request(req_time.isoformat(), uri, request.method, self.api_version,
+        event_req = self.event_mapper.to_request(req_time, uri, request.method, self.api_version,
                                                  ip_address, req_headers, req_body, req_body_transfer_encoding)
 
         # Prepare Event Response Model
-        event_rsp = self.event_mapper.to_response(rsp_time.isoformat(), response.status_code, rsp_headers, rsp_body,
+        event_rsp = self.event_mapper.to_response(rsp_time, response.status_code, rsp_headers, rsp_body,
                                                   rsp_body_transfer_encoding)
 
         # User Id
@@ -233,13 +233,20 @@ class MoesifMiddlewarePre19(object):
         if self.sampling_percentage >= random_percentage:
             event_model.weight = 1 if self.sampling_percentage == 0 else math.floor(100 / self.sampling_percentage)
             try:
-                if self.is_event_job_scheduled and datetime.utcnow() < self.last_event_job_run_time + timedelta(minutes=5):
-                    if self.DEBUG:
-                        print("Add Event to the queue")
-                    self.mo_events_queue.put(event_model)
-                else:
-                    self.schedule_event_background_job()
-                    self.is_event_job_scheduled = True
+                if not self.is_event_job_scheduled and datetime.utcnow() > self.last_event_job_run_time + timedelta(
+                        minutes=5):
+                    try:
+                        self.schedule_event_background_job()
+                        self.is_event_job_scheduled = True
+                        self.last_event_job_run_time = datetime.utcnow()
+                    except Exception as ex:
+                        self.is_event_job_scheduled = False
+                        if self.DEBUG:
+                            print('Error while starting the event scheduler job in background')
+                            print(str(ex))
+                if self.DEBUG:
+                    print("Add Event to the queue")
+                self.mo_events_queue.put(event_model)
             except Exception as ex:
                 if self.DEBUG:
                     print("Error while adding event to the queue")
